/***************************************************************************
 *   Copyright (C) 2005 by Oliver Saal                                     *
 *   http://www.oliver-saal.de/                                            *
 *   osaal@gmx.de                                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/ 

#include "config.h"
#include <qsettings.h>
#include <qdir.h>
#include <qurl.h>
#include <qapplication.h>
#include <qtextcodec.h>
#include <time.h>


CConfig::CConfig ()
{
	m_strQMPath = qApp->applicationDirPath()+"/translations/";
	QDir dir (m_strQMPath);
	if (dir.entryList("mautrechner_*.qm").isEmpty())
	{
		m_strQMPath = qApp->applicationDirPath()+"/../translations/";
		if (QDir(m_strQMPath).entryList("mautrechner_*.qm").isEmpty())
			m_strQMPath = QString ();
	}
	m_bShowAll = false;
	m_bAllowCrossesAsStart = false;

	m_iAxes = 0;
	m_iPollutant = 0;
}

CConfig::~CConfig ()
{
}

void CConfig::Load ()
{
QSettings set;
	set.setPath ("oliver-saal.de", "MautRechner", QSettings::User);
	m_strLocale = set.readEntry ("language", QTextCodec::locale());
	m_strDBFile = set.readEntry("database", QString());
	m_iDBVersion = set.readNumEntry ("dbversion", 0);
	m_bAllowCrossesAsStart = set.readBoolEntry("crosses", false);
	m_bShowAll = set.readBoolEntry ("showall", false);
	m_iAxes = set.readNumEntry ("axes", 0);
	m_iPollutant = set.readNumEntry ("pollutant", 0);
	m_uLastUpdate = set.readNumEntry ("lastupdate", 0);
	m_iUpdateInterval = set.readNumEntry ("updateinterval", -1);

	if (m_strDBFile.isEmpty())
	{
		FindDatabase ();
	}
}

void CConfig::Save ()
{
QSettings set;
	set.setPath ("oliver-saal.de", "MautRechner", QSettings::User);
	set.writeEntry ("language", m_strLocale);
	if (!m_strDBFile.isEmpty()) set.writeEntry ("database", m_strDBFile);
	set.writeEntry ("crosses", m_bAllowCrossesAsStart);
	set.writeEntry ("showall", m_bShowAll);
	set.writeEntry ("axes", m_iAxes);
	set.writeEntry ("pollutant", m_iPollutant);
	set.writeEntry ("dbversion", m_iDBVersion);
	set.writeEntry ("lastupdate", (int)m_uLastUpdate);
	set.writeEntry ("updateinterval", m_iUpdateInterval);
}

bool CConfig::UpdateCheckNow ()
{
unsigned uFaktor=0;
	switch (m_iUpdateInterval)
	{
	default:
	case 0:
		return false;
	case 1:
		uFaktor = 1;
		break;
	case 2:
		uFaktor = 7;
		break;
	case 3:
		uFaktor = 30;
		break;
	}
	uFaktor *= 24*3600;

	return (m_uLastUpdate + uFaktor < time (NULL));
}

static QString GetValue (QString strLine)
{
	return (strLine.mid (strLine.find('=')+1).stripWhiteSpace());
}

static QString GetKey (QString strLine)
{
	return (strLine.left (strLine.find('=')).stripWhiteSpace());
}

bool CConfig::FindDatabase ()
{
QString strFile = qApp->applicationDirPath()+"/../data/install.txt", strLine;
QFile file (strFile);
QTextStream stream;
	if (!file.open (IO_ReadOnly)) return false;
	stream.setDevice (&file);
	while (!stream.atEnd ())
	{
		strLine = stream.readLine ().stripWhiteSpace();
		if (strLine.isEmpty()) continue;
		if (strLine[0] == '#') continue;
		if (strLine.find ('=') < 0) continue;

		if (GetKey (strLine) == "file") m_strDBFile = QDir(qApp->applicationDirPath()+"/../data/").absPath() + "/" + GetValue(strLine);
		else if (GetKey (strLine) == "version") m_iDBVersion = GetValue(strLine).toInt();
	}
	if (!m_strDBFile.isEmpty() && m_iDBVersion > 0)
		return true;
	else
		return false;
}
