/***************************************************************************
 *   Copyright (C) 2005 by Oliver Saal                                     *
 *   http://www.oliver-saal.de/                                            *
 *   osaal@gmx.de                                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/ 

#ifndef VECTOR2D_H
#define VECTOR2D_H

#include <math.h>
#include <qpoint.h>

class CVector2D
{
public:
	CVector2D (const double x=0.0, const double y=0.0)
	{
		m_x = x;
		m_y = y;
	}

	CVector2D (const CVector2D &v)
	{
		m_x = v.x();
		m_y = v.y();
	}
	CVector2D (const QPoint &pt)
	{
		m_x = pt.x();
		m_y = pt.y();
	}

	~CVector2D () {}

	inline void setX (const double x) { m_x = x; }
	inline void setY (const double y) { m_y = y; }
	inline double x () const { return m_x; }
	inline double y () const { return m_y; }

	inline bool isNull () const { return (m_x == 0.0 && m_y == 0.0); }
	inline double len () const { return sqrt (m_x*m_x + m_y*m_y); }
	inline CVector2D vert () const { return CVector2D (m_y, -m_x); }

	CVector2D& makeIdentityLen ()
	{
		if (len() == 0.0) return (*this);
		m_x /= len ();
		m_y /= len ();
		return (*this);
	}

	QPoint toPoint () const { return QPoint ((int) m_x, (int) m_y); }

protected:
	double m_x;
	double m_y;
};

inline CVector2D operator + (const CVector2D& v1, const CVector2D& v2)
{
	return CVector2D (v1.x()+v2.x(), v1.y()+v2.y());
}

inline CVector2D operator - (const CVector2D& v1, const CVector2D& v2)
{
	return CVector2D (v1.x()-v2.x(), v1.y()-v2.y());
}

inline CVector2D operator * (const double d, const CVector2D& v)
{
	return CVector2D (d * v.x(), d * v.y());
}


#endif